pub enum ReadEvalSource {
Text(String),
Bytes(Vec<u8>),
Expr(Expr),
}Expand description
Source accepted by the read-eval broker.
Variants
Text(String)
Decode this text through the request codec before evaluation.
Bytes(Vec<u8>)
Decode these bytes through the request codec before evaluation.
Expr(Expr)
Evaluate an already-decoded expression.